# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/model.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13gateway/model.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9c\x05\n\x05Model\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x14 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12+\n\x05state\x18\x06 \x01(\x0e\x32\x14.gateway.Model.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x07 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12)\n\x04kind\x18\x04 \x01(\x0e\x32\x13.gateway.Model.KindB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1d\n\rdeployment_id\x18\x0f \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x17\n\ngithub_url\x18\x15 \x01(\tB\x03\xe0\x41\x01\x12\x1d\n\x10hugging_face_url\x18\x16 \x01(\tB\x03\xe0\x41\x01\x12=\n\x12\x62\x61se_model_details\x18\x17 \x01(\x0b\x32\x19.gateway.BaseModelDetailsB\x06\xe0\x41\x01\xe0\x41\x05\x12\x32\n\x0cpeft_details\x18\x10 \x01(\x0b\x32\x14.gateway.PEFTDetailsB\x06\xe0\x41\x01\xe0\x41\x05\x12\x13\n\x06public\x18\x13 \x01(\x08\x42\x03\xe0\x41\x01\"k\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\x0e\n\nUNDEPLOYED\x10\x02\x12\x0f\n\x0bUNDEPLOYING\x10\x03\x12\r\n\tDEPLOYING\x10\x04\x12\x0c\n\x08\x44\x45PLOYED\x10\x05\"B\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x11\n\rHF_BASE_MODEL\x10\x01\x12\x11\n\rHF_PEFT_ADDON\x10\x02\"\xf4\x01\n\x10\x42\x61seModelDetails\x12\x1a\n\nworld_size\x18\x01 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12M\n\x11\x63heckpoint_format\x18\x02 \x01(\x0e\x32*.gateway.BaseModelDetails.CheckpointFormatB\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11huggingface_files\x18\x03 \x03(\tB\x06\xe0\x41\x01\xe0\x41\x05\"R\n\x10\x43heckpointFormat\x12!\n\x1d\x43HECKPOINT_FORMAT_UNSPECIFIED\x10\x00\x12\n\n\x06NATIVE\x10\x01\x12\x0f\n\x0bHUGGINGFACE\x10\x02\"\\\n\x0bPEFTDetails\x12\x1a\n\nbase_model\x18\x01 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x11\n\x01r\x18\x02 \x01(\x05\x42\x06\xe0\x41\x02\xe0\x41\x05\x12\x1e\n\x0etarget_modules\x18\x03 \x03(\tB\x06\xe0\x41\x02\xe0\x41\x05\"d\n\x12\x43reateModelRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\"\n\x05model\x18\x02 \x01(\x0b\x32\x0e.gateway.ModelB\x03\xe0\x41\x02\x12\x15\n\x08model_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"$\n\x0fGetModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"C\n\x12\x44\x65ployModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x1a\n\rdeployment_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\")\n\x14UndeployModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\xc4\x01\n\x1dGetModelUploadEndpointRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12Y\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32:.gateway.GetModelUploadEndpointRequest.FilenameToSizeEntryB\x03\xe0\x41\x02\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xc1\x01\n\x1eGetModelUploadEndpointResponse\x12\x62\n\x17\x66ilename_to_signed_urls\x18\x05 \x03(\x0b\x32\x41.gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x1aValidateModelUploadRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x85\x01\n\x11ListModelsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"a\n\x12ListModelsResponse\x12\x1e\n\x06models\x18\x01 \x03(\x0b\x32\x0e.gateway.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"8\n\x12UpdateModelRequest\x12\"\n\x05model\x18\x01 \x01(\x0b\x32\x0e.gateway.ModelB\x03\xe0\x41\x02\"\'\n\x12\x44\x65leteModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.model_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _MODEL.fields_by_name['name']._options = None
  _MODEL.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _MODEL.fields_by_name['display_name']._options = None
  _MODEL.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['description']._options = None
  _MODEL.fields_by_name['description']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['create_time']._options = None
  _MODEL.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _MODEL.fields_by_name['state']._options = None
  _MODEL.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _MODEL.fields_by_name['status']._options = None
  _MODEL.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _MODEL.fields_by_name['kind']._options = None
  _MODEL.fields_by_name['kind']._serialized_options = b'\340A\001\340A\005'
  _MODEL.fields_by_name['deployment_id']._options = None
  _MODEL.fields_by_name['deployment_id']._serialized_options = b'\340A\003\340A\005'
  _MODEL.fields_by_name['github_url']._options = None
  _MODEL.fields_by_name['github_url']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['hugging_face_url']._options = None
  _MODEL.fields_by_name['hugging_face_url']._serialized_options = b'\340A\001'
  _MODEL.fields_by_name['base_model_details']._options = None
  _MODEL.fields_by_name['base_model_details']._serialized_options = b'\340A\001\340A\005'
  _MODEL.fields_by_name['peft_details']._options = None
  _MODEL.fields_by_name['peft_details']._serialized_options = b'\340A\001\340A\005'
  _MODEL.fields_by_name['public']._options = None
  _MODEL.fields_by_name['public']._serialized_options = b'\340A\001'
  _BASEMODELDETAILS.fields_by_name['world_size']._options = None
  _BASEMODELDETAILS.fields_by_name['world_size']._serialized_options = b'\340A\001\340A\005'
  _BASEMODELDETAILS.fields_by_name['checkpoint_format']._options = None
  _BASEMODELDETAILS.fields_by_name['checkpoint_format']._serialized_options = b'\340A\001\340A\005'
  _BASEMODELDETAILS.fields_by_name['huggingface_files']._options = None
  _BASEMODELDETAILS.fields_by_name['huggingface_files']._serialized_options = b'\340A\001\340A\005'
  _PEFTDETAILS.fields_by_name['base_model']._options = None
  _PEFTDETAILS.fields_by_name['base_model']._serialized_options = b'\340A\002\340A\005'
  _PEFTDETAILS.fields_by_name['r']._options = None
  _PEFTDETAILS.fields_by_name['r']._serialized_options = b'\340A\002\340A\005'
  _PEFTDETAILS.fields_by_name['target_modules']._options = None
  _PEFTDETAILS.fields_by_name['target_modules']._serialized_options = b'\340A\002\340A\005'
  _CREATEMODELREQUEST.fields_by_name['parent']._options = None
  _CREATEMODELREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEMODELREQUEST.fields_by_name['model']._options = None
  _CREATEMODELREQUEST.fields_by_name['model']._serialized_options = b'\340A\002'
  _CREATEMODELREQUEST.fields_by_name['model_id']._options = None
  _CREATEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\002'
  _GETMODELREQUEST.fields_by_name['name']._options = None
  _GETMODELREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _DEPLOYMODELREQUEST.fields_by_name['name']._options = None
  _DEPLOYMODELREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _DEPLOYMODELREQUEST.fields_by_name['deployment_id']._options = None
  _DEPLOYMODELREQUEST.fields_by_name['deployment_id']._serialized_options = b'\340A\002'
  _UNDEPLOYMODELREQUEST.fields_by_name['name']._options = None
  _UNDEPLOYMODELREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY._options = None
  _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY._serialized_options = b'8\001'
  _GETMODELUPLOADENDPOINTREQUEST.fields_by_name['name']._options = None
  _GETMODELUPLOADENDPOINTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _GETMODELUPLOADENDPOINTREQUEST.fields_by_name['filename_to_size']._options = None
  _GETMODELUPLOADENDPOINTREQUEST.fields_by_name['filename_to_size']._serialized_options = b'\340A\002'
  _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY._options = None
  _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY._serialized_options = b'8\001'
  _VALIDATEMODELUPLOADREQUEST.fields_by_name['name']._options = None
  _VALIDATEMODELUPLOADREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTMODELSREQUEST.fields_by_name['parent']._options = None
  _LISTMODELSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['filter']._options = None
  _LISTMODELSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTMODELSREQUEST.fields_by_name['order_by']._options = None
  _LISTMODELSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATEMODELREQUEST.fields_by_name['model']._options = None
  _UPDATEMODELREQUEST.fields_by_name['model']._serialized_options = b'\340A\002'
  _DELETEMODELREQUEST.fields_by_name['name']._options = None
  _DELETEMODELREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _MODEL._serialized_start=121
  _MODEL._serialized_end=789
  _MODEL_STATE._serialized_start=614
  _MODEL_STATE._serialized_end=721
  _MODEL_KIND._serialized_start=723
  _MODEL_KIND._serialized_end=789
  _BASEMODELDETAILS._serialized_start=792
  _BASEMODELDETAILS._serialized_end=1036
  _BASEMODELDETAILS_CHECKPOINTFORMAT._serialized_start=954
  _BASEMODELDETAILS_CHECKPOINTFORMAT._serialized_end=1036
  _PEFTDETAILS._serialized_start=1038
  _PEFTDETAILS._serialized_end=1130
  _CREATEMODELREQUEST._serialized_start=1132
  _CREATEMODELREQUEST._serialized_end=1232
  _GETMODELREQUEST._serialized_start=1234
  _GETMODELREQUEST._serialized_end=1270
  _DEPLOYMODELREQUEST._serialized_start=1272
  _DEPLOYMODELREQUEST._serialized_end=1339
  _UNDEPLOYMODELREQUEST._serialized_start=1341
  _UNDEPLOYMODELREQUEST._serialized_end=1382
  _GETMODELUPLOADENDPOINTREQUEST._serialized_start=1385
  _GETMODELUPLOADENDPOINTREQUEST._serialized_end=1581
  _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY._serialized_start=1528
  _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY._serialized_end=1581
  _GETMODELUPLOADENDPOINTRESPONSE._serialized_start=1584
  _GETMODELUPLOADENDPOINTRESPONSE._serialized_end=1777
  _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY._serialized_start=1718
  _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY._serialized_end=1777
  _VALIDATEMODELUPLOADREQUEST._serialized_start=1779
  _VALIDATEMODELUPLOADREQUEST._serialized_end=1826
  _LISTMODELSREQUEST._serialized_start=1829
  _LISTMODELSREQUEST._serialized_end=1962
  _LISTMODELSRESPONSE._serialized_start=1964
  _LISTMODELSRESPONSE._serialized_end=2061
  _UPDATEMODELREQUEST._serialized_start=2063
  _UPDATEMODELREQUEST._serialized_end=2119
  _DELETEMODELREQUEST._serialized_start=2121
  _DELETEMODELREQUEST._serialized_end=2160
# @@protoc_insertion_point(module_scope)
