# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/gateway.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import account_pb2 as gateway_dot_account__pb2
from . import aws_iam_role_binding_pb2 as gateway_dot_aws__iam__role__binding__pb2
from . import batch_job_pb2 as gateway_dot_batch__job__pb2
from . import cluster_pb2 as gateway_dot_cluster__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import environment_pb2 as gateway_dot_environment__pb2
from . import model_pb2 as gateway_dot_model__pb2
from . import node_pool_pb2 as gateway_dot_node__pool__pb2
from . import sign_in_pb2 as gateway_dot_sign__in__pb2
from . import snapshot_pb2 as gateway_dot_snapshot__pb2
from . import user_pb2 as gateway_dot_user__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/gateway.proto\x12\x07gateway\x1a\x15gateway/account.proto\x1a\"gateway/aws_iam_role_binding.proto\x1a\x17gateway/batch_job.proto\x1a\x15gateway/cluster.proto\x1a\x18gateway/deployment.proto\x1a\x19gateway/environment.proto\x1a\x13gateway/model.proto\x1a\x17gateway/node_pool.proto\x1a\x15gateway/sign_in.proto\x1a\x16gateway/snapshot.proto\x1a\x12gateway/user.proto\x1a\x1bgoogle/protobuf/empty.proto2\xa4%\n\x07Gateway\x12:\n\x06SignIn\x12\x16.gateway.SignInRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x11GetOAuthArguments\x12!.gateway.GetOAuthArgumentsRequest\x1a\".gateway.GetOAuthArgumentsResponse\"\x00\x12\x42\n\rCreateAccount\x12\x1d.gateway.CreateAccountRequest\x1a\x10.gateway.Account\"\x00\x12<\n\nGetAccount\x12\x1a.gateway.GetAccountRequest\x1a\x10.gateway.Account\"\x00\x12M\n\x0cListAccounts\x12\x1c.gateway.ListAccountsRequest\x1a\x1d.gateway.ListAccountsResponse\"\x00\x12\x42\n\rUpdateAccount\x12\x1d.gateway.UpdateAccountRequest\x1a\x10.gateway.Account\"\x00\x12H\n\rDeleteAccount\x12\x1d.gateway.DeleteAccountRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x45\n\x0e\x43reateBatchJob\x12\x1e.gateway.CreateBatchJobRequest\x1a\x11.gateway.BatchJob\"\x00\x12?\n\x0bGetBatchJob\x12\x1b.gateway.GetBatchJobRequest\x1a\x11.gateway.BatchJob\"\x00\x12P\n\rListBatchJobs\x12\x1d.gateway.ListBatchJobsRequest\x1a\x1e.gateway.ListBatchJobsResponse\"\x00\x12J\n\x0e\x44\x65leteBatchJob\x12\x1e.gateway.DeleteBatchJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x14\x42\x61tchDeleteBatchJobs\x12$.gateway.BatchDeleteBatchJobsRequest\x1a\x16.google.protobuf.Empty\"\x00\x12J\n\x0e\x43\x61ncelBatchJob\x12\x1e.gateway.CancelBatchJobRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x42\n\rCreateCluster\x12\x1d.gateway.CreateClusterRequest\x1a\x10.gateway.Cluster\"\x00\x12<\n\nGetCluster\x12\x1a.gateway.GetClusterRequest\x1a\x10.gateway.Cluster\"\x00\x12M\n\x0cListClusters\x12\x1c.gateway.ListClustersRequest\x1a\x1d.gateway.ListClustersResponse\"\x00\x12\x42\n\rUpdateCluster\x12\x1d.gateway.UpdateClusterRequest\x1a\x10.gateway.Cluster\"\x00\x12H\n\rDeleteCluster\x12\x1d.gateway.DeleteClusterRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x18GetClusterConnectionInfo\x12(.gateway.GetClusterConnectionInfoRequest\x1a\x1e.gateway.ClusterConnectionInfo\"\x00\x12N\n\x11\x43reateEnvironment\x12!.gateway.CreateEnvironmentRequest\x1a\x14.gateway.Environment\"\x00\x12H\n\x0eGetEnvironment\x12\x1e.gateway.GetEnvironmentRequest\x1a\x14.gateway.Environment\"\x00\x12Y\n\x10ListEnvironments\x12 .gateway.ListEnvironmentsRequest\x1a!.gateway.ListEnvironmentsResponse\"\x00\x12N\n\x11UpdateEnvironment\x12!.gateway.UpdateEnvironmentRequest\x1a\x14.gateway.Environment\"\x00\x12P\n\x11\x44\x65leteEnvironment\x12!.gateway.DeleteEnvironmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x17\x42\x61tchDeleteEnvironments\x12\'.gateway.BatchDeleteEnvironmentsRequest\x1a\x16.google.protobuf.Empty\"\x00\x12R\n\x12\x43onnectEnvironment\x12\".gateway.ConnectEnvironmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12X\n\x15\x44isconnectEnvironment\x12%.gateway.DisconnectEnvironmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12?\n\x0bGetSnapshot\x12\x1b.gateway.GetSnapshotRequest\x1a\x11.gateway.Snapshot\"\x00\x12P\n\rListSnapshots\x12\x1d.gateway.ListSnapshotsRequest\x1a\x1e.gateway.ListSnapshotsResponse\"\x00\x12V\n\x0fGetBatchJobLogs\x12\x1f.gateway.GetBatchJobLogsRequest\x1a .gateway.GetBatchJobLogsResponse\"\x00\x12\x45\n\x0e\x43reateNodePool\x12\x1e.gateway.CreateNodePoolRequest\x1a\x11.gateway.NodePool\"\x00\x12?\n\x0bGetNodePool\x12\x1b.gateway.GetNodePoolRequest\x1a\x11.gateway.NodePool\"\x00\x12P\n\rListNodePools\x12\x1d.gateway.ListNodePoolsRequest\x1a\x1e.gateway.ListNodePoolsResponse\"\x00\x12\x45\n\x0eUpdateNodePool\x12\x1e.gateway.UpdateNodePoolRequest\x1a\x11.gateway.NodePool\"\x00\x12J\n\x0e\x44\x65leteNodePool\x12\x1e.gateway.DeleteNodePoolRequest\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x14\x42\x61tchDeleteNodePools\x12$.gateway.BatchDeleteNodePoolsRequest\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\x10GetNodePoolStats\x12 .gateway.GetNodePoolStatsRequest\x1a\x16.gateway.NodePoolStats\"\x00\x12\x39\n\nCreateUser\x12\x1a.gateway.CreateUserRequest\x1a\r.gateway.User\"\x00\x12\x33\n\x07GetUser\x12\x17.gateway.GetUserRequest\x1a\r.gateway.User\"\x00\x12\x44\n\tListUsers\x12\x19.gateway.ListUsersRequest\x1a\x1a.gateway.ListUsersResponse\"\x00\x12\x39\n\nUpdateUser\x12\x1a.gateway.UpdateUserRequest\x1a\r.gateway.User\"\x00\x12\x42\n\nDeleteUser\x12\x1a.gateway.DeleteUserRequest\x1a\x16.google.protobuf.Empty\"\x00\x12<\n\x0b\x43reateModel\x12\x1b.gateway.CreateModelRequest\x1a\x0e.gateway.Model\"\x00\x12\x36\n\x08GetModel\x12\x18.gateway.GetModelRequest\x1a\x0e.gateway.Model\"\x00\x12G\n\nListModels\x12\x1a.gateway.ListModelsRequest\x1a\x1b.gateway.ListModelsResponse\"\x00\x12<\n\x0bUpdateModel\x12\x1b.gateway.UpdateModelRequest\x1a\x0e.gateway.Model\"\x00\x12\x44\n\x0b\x44\x65leteModel\x12\x1b.gateway.DeleteModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12k\n\x16GetModelUploadEndpoint\x12&.gateway.GetModelUploadEndpointRequest\x1a\'.gateway.GetModelUploadEndpointResponse\"\x00\x12T\n\x13ValidateModelUpload\x12#.gateway.ValidateModelUploadRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x44\n\x0b\x44\x65ployModel\x12\x1b.gateway.DeployModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12H\n\rUndeployModel\x12\x1d.gateway.UndeployModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12K\n\x10\x43reateDeployment\x12 .gateway.CreateDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12\x45\n\rGetDeployment\x12\x1d.gateway.GetDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12I\n\x0fStartDeployment\x12\x1f.gateway.StartDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12V\n\x0fListDeployments\x12\x1f.gateway.ListDeploymentsRequest\x1a .gateway.ListDeploymentsResponse\"\x00\x12K\n\x10UpdateDeployment\x12 .gateway.UpdateDeploymentRequest\x1a\x13.gateway.Deployment\"\x00\x12N\n\x10\x44\x65leteDeployment\x12 .gateway.DeleteDeploymentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12`\n\x17\x43reateAwsIamRoleBinding\x12\'.gateway.CreateAwsIamRoleBindingRequest\x1a\x1a.gateway.AwsIamRoleBinding\"\x00\x12k\n\x16ListAwsIamRoleBindings\x12&.gateway.ListAwsIamRoleBindingsRequest\x1a\'.gateway.ListAwsIamRoleBindingsResponse\"\x00\x12\\\n\x17\x44\x65leteAwsIamRoleBinding\x12\'.gateway.DeleteAwsIamRoleBindingRequest\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\x10ReconcileCluster\x12 .gateway.ReconcileClusterRequest\x1a\x16.google.protobuf.Empty\"\x00\x12P\n\x11ReconcileNodePool\x12!.gateway.ReconcileNodePoolRequest\x1a\x16.google.protobuf.Empty\"\x00\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.gateway_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _GATEWAY._serialized_start=337
  _GATEWAY._serialized_end=5109
# @@protoc_insertion_point(module_scope)
