# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/batch_job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/batch_job.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x08\n\x08\x42\x61tchJob\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\t \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x36\n\nstart_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x34\n\x08\x65nd_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\ncreated_by\x18\r \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1c\n\x0cnode_pool_id\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x1e\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1b\n\x0bsnapshot_id\x18\x13 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x19\n\tnum_ranks\x18\x0b \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x38\n\x08\x65nv_vars\x18\x06 \x03(\x0b\x32\x1e.gateway.BatchJob.EnvVarsEntryB\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04role\x18\x11 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x32\n\x0fpython_executor\x18\x07 \x01(\x0b\x32\x17.gateway.PythonExecutorH\x00\x12\x36\n\x11notebook_executor\x18\x08 \x01(\x0b\x32\x19.gateway.NotebookExecutorH\x00\x12\x30\n\x0eshell_executor\x18\x10 \x01(\x0b\x32\x16.gateway.ShellExecutorH\x00\x12\x19\n\timage_ref\x18\n \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12?\n\x0b\x61nnotations\x18\x12 \x03(\x0b\x32\".gateway.BatchJob.AnnotationsEntryB\x06\xe0\x41\x01\xe0\x41\x05\x12.\n\x05state\x18\x04 \x01(\x0e\x32\x17.gateway.BatchJob.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\x16\n\x06status\x18\x05 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x0e\n\x06shared\x18\x14 \x01(\x08\x1a.\n\x0c\x45nvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x07\x12\n\n\x06QUEUED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0e\n\nCANCELLING\x10\x08\x12\r\n\tCANCELLED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\tB\n\n\x08\x65xecutor\"W\n\x15\x43reateBatchJobRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12)\n\tbatch_job\x18\x02 \x01(\x0b\x32\x11.gateway.BatchJobB\x03\xe0\x41\x02\"\'\n\x12GetBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x88\x01\n\x14ListBatchJobsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"k\n\x15ListBatchJobsResponse\x12%\n\nbatch_jobs\x18\x01 \x03(\x0b\x32\x11.gateway.BatchJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"*\n\x15\x44\x65leteBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"F\n\x1b\x42\x61tchDeleteBatchJobsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05names\x18\x02 \x03(\tB\x03\xe0\x41\x02\"*\n\x15\x43\x61ncelBatchJobRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\xd3\x01\n\x16GetBatchJobLogsRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\r\n\x05ranks\x18\x03 \x03(\x05\x12\x16\n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x05 \x01(\tB\x03\xe0\x41\x01\x12\x33\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x07 \x01(\tB\x03\xe0\x41\x01\x12\x1c\n\x0fstart_from_head\x18\x08 \x01(\x08\x42\x03\xe0\x41\x01\"V\n\x17GetBatchJobLogsResponse\x12\"\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x11.gateway.LogEntry\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\xbb\x01\n\x0ePythonExecutor\x12<\n\x0btarget_type\x18\x01 \x01(\x0e\x32\".gateway.PythonExecutor.TargetTypeB\x03\xe0\x41\x02\x12\x13\n\x06target\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04\x61rgs\x18\x03 \x03(\tB\x03\xe0\x41\x01\"C\n\nTargetType\x12\x1b\n\x17TARGET_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MODULE\x10\x01\x12\x0c\n\x08\x46ILENAME\x10\x02\"%\n\rShellExecutor\x12\x14\n\x07\x63ommand\x18\x01 \x01(\tB\x03\xe0\x41\x02\"2\n\x10NotebookExecutor\x12\x1e\n\x11notebook_filename\x18\x01 \x01(\tB\x03\xe0\x41\x02\"W\n\x08LogEntry\x12,\n\x08log_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04rank\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\tB\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.batch_job_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _BATCHJOB_ENVVARSENTRY._options = None
  _BATCHJOB_ENVVARSENTRY._serialized_options = b'8\001'
  _BATCHJOB_ANNOTATIONSENTRY._options = None
  _BATCHJOB_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _BATCHJOB.fields_by_name['name']._options = None
  _BATCHJOB.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['display_name']._options = None
  _BATCHJOB.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _BATCHJOB.fields_by_name['create_time']._options = None
  _BATCHJOB.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['start_time']._options = None
  _BATCHJOB.fields_by_name['start_time']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['end_time']._options = None
  _BATCHJOB.fields_by_name['end_time']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['created_by']._options = None
  _BATCHJOB.fields_by_name['created_by']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['node_pool_id']._options = None
  _BATCHJOB.fields_by_name['node_pool_id']._serialized_options = b'\340A\002\340A\005'
  _BATCHJOB.fields_by_name['environment_id']._options = None
  _BATCHJOB.fields_by_name['environment_id']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['snapshot_id']._options = None
  _BATCHJOB.fields_by_name['snapshot_id']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['num_ranks']._options = None
  _BATCHJOB.fields_by_name['num_ranks']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['env_vars']._options = None
  _BATCHJOB.fields_by_name['env_vars']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['role']._options = None
  _BATCHJOB.fields_by_name['role']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['image_ref']._options = None
  _BATCHJOB.fields_by_name['image_ref']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['annotations']._options = None
  _BATCHJOB.fields_by_name['annotations']._serialized_options = b'\340A\001\340A\005'
  _BATCHJOB.fields_by_name['state']._options = None
  _BATCHJOB.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _BATCHJOB.fields_by_name['status']._options = None
  _BATCHJOB.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _CREATEBATCHJOBREQUEST.fields_by_name['parent']._options = None
  _CREATEBATCHJOBREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._options = None
  _CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._serialized_options = b'\340A\002'
  _GETBATCHJOBREQUEST.fields_by_name['name']._options = None
  _GETBATCHJOBREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTBATCHJOBSREQUEST.fields_by_name['parent']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTBATCHJOBSREQUEST.fields_by_name['page_size']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['page_token']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['filter']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['order_by']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _DELETEBATCHJOBREQUEST.fields_by_name['name']._options = None
  _DELETEBATCHJOBREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _BATCHDELETEBATCHJOBSREQUEST.fields_by_name['parent']._options = None
  _BATCHDELETEBATCHJOBSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _BATCHDELETEBATCHJOBSREQUEST.fields_by_name['names']._options = None
  _BATCHDELETEBATCHJOBSREQUEST.fields_by_name['names']._serialized_options = b'\340A\002'
  _CANCELBATCHJOBREQUEST.fields_by_name['name']._options = None
  _CANCELBATCHJOBREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['name']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['page_size']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['page_token']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['start_time']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['start_time']._serialized_options = b'\340A\001'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['filter']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _GETBATCHJOBLOGSREQUEST.fields_by_name['start_from_head']._options = None
  _GETBATCHJOBLOGSREQUEST.fields_by_name['start_from_head']._serialized_options = b'\340A\001'
  _PYTHONEXECUTOR.fields_by_name['target_type']._options = None
  _PYTHONEXECUTOR.fields_by_name['target_type']._serialized_options = b'\340A\002'
  _PYTHONEXECUTOR.fields_by_name['target']._options = None
  _PYTHONEXECUTOR.fields_by_name['target']._serialized_options = b'\340A\002'
  _PYTHONEXECUTOR.fields_by_name['args']._options = None
  _PYTHONEXECUTOR.fields_by_name['args']._serialized_options = b'\340A\001'
  _SHELLEXECUTOR.fields_by_name['command']._options = None
  _SHELLEXECUTOR.fields_by_name['command']._serialized_options = b'\340A\002'
  _NOTEBOOKEXECUTOR.fields_by_name['notebook_filename']._options = None
  _NOTEBOOKEXECUTOR.fields_by_name['notebook_filename']._serialized_options = b'\340A\002'
  _BATCHJOB._serialized_start=103
  _BATCHJOB._serialized_end=1162
  _BATCHJOB_ENVVARSENTRY._serialized_start=895
  _BATCHJOB_ENVVARSENTRY._serialized_end=941
  _BATCHJOB_ANNOTATIONSENTRY._serialized_start=943
  _BATCHJOB_ANNOTATIONSENTRY._serialized_end=993
  _BATCHJOB_STATE._serialized_start=996
  _BATCHJOB_STATE._serialized_end=1150
  _CREATEBATCHJOBREQUEST._serialized_start=1164
  _CREATEBATCHJOBREQUEST._serialized_end=1251
  _GETBATCHJOBREQUEST._serialized_start=1253
  _GETBATCHJOBREQUEST._serialized_end=1292
  _LISTBATCHJOBSREQUEST._serialized_start=1295
  _LISTBATCHJOBSREQUEST._serialized_end=1431
  _LISTBATCHJOBSRESPONSE._serialized_start=1433
  _LISTBATCHJOBSRESPONSE._serialized_end=1540
  _DELETEBATCHJOBREQUEST._serialized_start=1542
  _DELETEBATCHJOBREQUEST._serialized_end=1584
  _BATCHDELETEBATCHJOBSREQUEST._serialized_start=1586
  _BATCHDELETEBATCHJOBSREQUEST._serialized_end=1656
  _CANCELBATCHJOBREQUEST._serialized_start=1658
  _CANCELBATCHJOBREQUEST._serialized_end=1700
  _GETBATCHJOBLOGSREQUEST._serialized_start=1703
  _GETBATCHJOBLOGSREQUEST._serialized_end=1914
  _GETBATCHJOBLOGSRESPONSE._serialized_start=1916
  _GETBATCHJOBLOGSRESPONSE._serialized_end=2002
  _PYTHONEXECUTOR._serialized_start=2005
  _PYTHONEXECUTOR._serialized_end=2192
  _PYTHONEXECUTOR_TARGETTYPE._serialized_start=2125
  _PYTHONEXECUTOR_TARGETTYPE._serialized_end=2192
  _SHELLEXECUTOR._serialized_start=2194
  _SHELLEXECUTOR._serialized_end=2231
  _NOTEBOOKEXECUTOR._serialized_start=2233
  _NOTEBOOKEXECUTOR._serialized_end=2283
  _LOGENTRY._serialized_start=2285
  _LOGENTRY._serialized_end=2372
# @@protoc_insertion_point(module_scope)
