# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/environment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gateway/environment.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8f\x05\n\x0b\x45nvironment\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\ncreated_by\x18\x06 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x31\n\x05state\x18\n \x01(\x0e\x32\x1a.gateway.Environment.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x0b \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12:\n\nconnection\x18\x02 \x01(\x0b\x32\x1e.gateway.EnvironmentConnectionB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1e\n\x0e\x62\x61se_image_ref\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x19\n\timage_ref\x18\x04 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\"\n\x12snapshot_image_ref\x18\x08 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x0e\n\x06shared\x18\x0c \x01(\x08\x12?\n\x0b\x61nnotations\x18\t \x03(\x0b\x32%.gateway.Environment.AnnotationsEntryB\x03\xe0\x41\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x10\n\x0c\x44ISCONNECTED\x10\x02\x12\x0e\n\nCONNECTING\x10\x03\x12\r\n\tCONNECTED\x10\x04\x12\x11\n\rDISCONNECTING\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\"s\n\x15\x45nvironmentConnection\x12\x19\n\x0cnode_pool_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tnum_ranks\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01\x12\x11\n\x04role\x18\x06 \x01(\tB\x03\xe0\x41\x01\x12\x14\n\x04zone\x18\x05 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\"|\n\x18\x43reateEnvironmentRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12.\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x14.gateway.EnvironmentB\x03\xe0\x41\x02\x12\x1b\n\x0e\x65nvironment_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"*\n\x15GetEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x8b\x01\n\x17ListEnvironmentsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"s\n\x18ListEnvironmentsResponse\x12*\n\x0c\x65nvironments\x18\x01 \x03(\x0b\x32\x14.gateway.Environment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"J\n\x18UpdateEnvironmentRequest\x12.\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x14.gateway.EnvironmentB\x03\xe0\x41\x02\"-\n\x18\x44\x65leteEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"I\n\x1e\x42\x61tchDeleteEnvironmentsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05names\x18\x02 \x03(\tB\x03\xe0\x41\x02\"\x84\x01\n\x19\x43onnectEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x37\n\nconnection\x18\x02 \x01(\x0b\x32\x1e.gateway.EnvironmentConnectionB\x03\xe0\x41\x02\x12\x1b\n\x0evscode_version\x18\x03 \x01(\tB\x03\xe0\x41\x01\"c\n\x1c\x44isconnectEnvironmentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05\x66orce\x18\x02 \x01(\x08\x42\x03\xe0\x41\x01\x12\x1c\n\x0freset_snapshots\x18\x03 \x01(\x08\x42\x03\xe0\x41\x01\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.environment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _ENVIRONMENT_ANNOTATIONSENTRY._options = None
  _ENVIRONMENT_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _ENVIRONMENT.fields_by_name['name']._options = None
  _ENVIRONMENT.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['display_name']._options = None
  _ENVIRONMENT.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _ENVIRONMENT.fields_by_name['create_time']._options = None
  _ENVIRONMENT.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['created_by']._options = None
  _ENVIRONMENT.fields_by_name['created_by']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['state']._options = None
  _ENVIRONMENT.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['status']._options = None
  _ENVIRONMENT.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['connection']._options = None
  _ENVIRONMENT.fields_by_name['connection']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['base_image_ref']._options = None
  _ENVIRONMENT.fields_by_name['base_image_ref']._serialized_options = b'\340A\001\340A\005'
  _ENVIRONMENT.fields_by_name['image_ref']._options = None
  _ENVIRONMENT.fields_by_name['image_ref']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['snapshot_image_ref']._options = None
  _ENVIRONMENT.fields_by_name['snapshot_image_ref']._serialized_options = b'\340A\003\340A\005'
  _ENVIRONMENT.fields_by_name['annotations']._options = None
  _ENVIRONMENT.fields_by_name['annotations']._serialized_options = b'\340A\001'
  _ENVIRONMENTCONNECTION.fields_by_name['node_pool_id']._options = None
  _ENVIRONMENTCONNECTION.fields_by_name['node_pool_id']._serialized_options = b'\340A\002'
  _ENVIRONMENTCONNECTION.fields_by_name['num_ranks']._options = None
  _ENVIRONMENTCONNECTION.fields_by_name['num_ranks']._serialized_options = b'\340A\001'
  _ENVIRONMENTCONNECTION.fields_by_name['role']._options = None
  _ENVIRONMENTCONNECTION.fields_by_name['role']._serialized_options = b'\340A\001'
  _ENVIRONMENTCONNECTION.fields_by_name['zone']._options = None
  _ENVIRONMENTCONNECTION.fields_by_name['zone']._serialized_options = b'\340A\003\340A\005'
  _CREATEENVIRONMENTREQUEST.fields_by_name['parent']._options = None
  _CREATEENVIRONMENTREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEENVIRONMENTREQUEST.fields_by_name['environment']._options = None
  _CREATEENVIRONMENTREQUEST.fields_by_name['environment']._serialized_options = b'\340A\002'
  _CREATEENVIRONMENTREQUEST.fields_by_name['environment_id']._options = None
  _CREATEENVIRONMENTREQUEST.fields_by_name['environment_id']._serialized_options = b'\340A\002'
  _GETENVIRONMENTREQUEST.fields_by_name['name']._options = None
  _GETENVIRONMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTENVIRONMENTSREQUEST.fields_by_name['parent']._options = None
  _LISTENVIRONMENTSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTENVIRONMENTSREQUEST.fields_by_name['page_size']._options = None
  _LISTENVIRONMENTSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTENVIRONMENTSREQUEST.fields_by_name['page_token']._options = None
  _LISTENVIRONMENTSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTENVIRONMENTSREQUEST.fields_by_name['filter']._options = None
  _LISTENVIRONMENTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTENVIRONMENTSREQUEST.fields_by_name['order_by']._options = None
  _LISTENVIRONMENTSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATEENVIRONMENTREQUEST.fields_by_name['environment']._options = None
  _UPDATEENVIRONMENTREQUEST.fields_by_name['environment']._serialized_options = b'\340A\002'
  _DELETEENVIRONMENTREQUEST.fields_by_name['name']._options = None
  _DELETEENVIRONMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _BATCHDELETEENVIRONMENTSREQUEST.fields_by_name['parent']._options = None
  _BATCHDELETEENVIRONMENTSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _BATCHDELETEENVIRONMENTSREQUEST.fields_by_name['names']._options = None
  _BATCHDELETEENVIRONMENTSREQUEST.fields_by_name['names']._serialized_options = b'\340A\002'
  _CONNECTENVIRONMENTREQUEST.fields_by_name['name']._options = None
  _CONNECTENVIRONMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _CONNECTENVIRONMENTREQUEST.fields_by_name['connection']._options = None
  _CONNECTENVIRONMENTREQUEST.fields_by_name['connection']._serialized_options = b'\340A\002'
  _CONNECTENVIRONMENTREQUEST.fields_by_name['vscode_version']._options = None
  _CONNECTENVIRONMENTREQUEST.fields_by_name['vscode_version']._serialized_options = b'\340A\001'
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['name']._options = None
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['force']._options = None
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['force']._serialized_options = b'\340A\001'
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['reset_snapshots']._options = None
  _DISCONNECTENVIRONMENTREQUEST.fields_by_name['reset_snapshots']._serialized_options = b'\340A\001'
  _ENVIRONMENT._serialized_start=127
  _ENVIRONMENT._serialized_end=782
  _ENVIRONMENT_ANNOTATIONSENTRY._serialized_start=604
  _ENVIRONMENT_ANNOTATIONSENTRY._serialized_end=654
  _ENVIRONMENT_STATE._serialized_start=656
  _ENVIRONMENT_STATE._serialized_end=782
  _ENVIRONMENTCONNECTION._serialized_start=784
  _ENVIRONMENTCONNECTION._serialized_end=899
  _CREATEENVIRONMENTREQUEST._serialized_start=901
  _CREATEENVIRONMENTREQUEST._serialized_end=1025
  _GETENVIRONMENTREQUEST._serialized_start=1027
  _GETENVIRONMENTREQUEST._serialized_end=1069
  _LISTENVIRONMENTSREQUEST._serialized_start=1072
  _LISTENVIRONMENTSREQUEST._serialized_end=1211
  _LISTENVIRONMENTSRESPONSE._serialized_start=1213
  _LISTENVIRONMENTSRESPONSE._serialized_end=1328
  _UPDATEENVIRONMENTREQUEST._serialized_start=1330
  _UPDATEENVIRONMENTREQUEST._serialized_end=1404
  _DELETEENVIRONMENTREQUEST._serialized_start=1406
  _DELETEENVIRONMENTREQUEST._serialized_end=1451
  _BATCHDELETEENVIRONMENTSREQUEST._serialized_start=1453
  _BATCHDELETEENVIRONMENTSREQUEST._serialized_end=1526
  _CONNECTENVIRONMENTREQUEST._serialized_start=1529
  _CONNECTENVIRONMENTREQUEST._serialized_end=1661
  _DISCONNECTENVIRONMENTREQUEST._serialized_start=1663
  _DISCONNECTENVIRONMENTREQUEST._serialized_end=1762
# @@protoc_insertion_point(module_scope)
