# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/aws_iam_role_binding.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"gateway/aws_iam_role_binding.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x93\x01\n\x11\x41wsIamRoleBinding\x12\x1a\n\naccount_id\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x37\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x16\n\tprincipal\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04role\x18\x04 \x01(\tB\x03\xe0\x41\x02\"t\n\x1e\x43reateAwsIamRoleBindingRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12=\n\x14\x61ws_iam_role_binding\x18\x02 \x01(\x0b\x32\x1a.gateway.AwsIamRoleBindingB\x03\xe0\x41\x02\"\x91\x01\n\x1dListAwsIamRoleBindingsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"\x88\x01\n\x1eListAwsIamRoleBindingsResponse\x12\x39\n\x15\x61ws_iam_role_bindings\x18\x01 \x03(\x0b\x32\x1a.gateway.AwsIamRoleBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"_\n\x1e\x44\x65leteAwsIamRoleBindingRequest\x12=\n\x14\x61ws_iam_role_binding\x18\x02 \x01(\x0b\x32\x1a.gateway.AwsIamRoleBindingB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.aws_iam_role_binding_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _AWSIAMROLEBINDING.fields_by_name['account_id']._options = None
  _AWSIAMROLEBINDING.fields_by_name['account_id']._serialized_options = b'\340A\003\340A\005'
  _AWSIAMROLEBINDING.fields_by_name['create_time']._options = None
  _AWSIAMROLEBINDING.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _AWSIAMROLEBINDING.fields_by_name['principal']._options = None
  _AWSIAMROLEBINDING.fields_by_name['principal']._serialized_options = b'\340A\002'
  _AWSIAMROLEBINDING.fields_by_name['role']._options = None
  _AWSIAMROLEBINDING.fields_by_name['role']._serialized_options = b'\340A\002'
  _CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['parent']._options = None
  _CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._options = None
  _CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._serialized_options = b'\340A\002'
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['parent']._options = None
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_size']._options = None
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_token']._options = None
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['filter']._options = None
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['order_by']._options = None
  _LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _DELETEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._options = None
  _DELETEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._serialized_options = b'\340A\002'
  _AWSIAMROLEBINDING._serialized_start=114
  _AWSIAMROLEBINDING._serialized_end=261
  _CREATEAWSIAMROLEBINDINGREQUEST._serialized_start=263
  _CREATEAWSIAMROLEBINDINGREQUEST._serialized_end=379
  _LISTAWSIAMROLEBINDINGSREQUEST._serialized_start=382
  _LISTAWSIAMROLEBINDINGSREQUEST._serialized_end=527
  _LISTAWSIAMROLEBINDINGSRESPONSE._serialized_start=530
  _LISTAWSIAMROLEBINDINGSRESPONSE._serialized_end=666
  _DELETEAWSIAMROLEBINDINGREQUEST._serialized_start=668
  _DELETEAWSIAMROLEBINDINGREQUEST._serialized_end=763
# @@protoc_insertion_point(module_scope)
