# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12gateway/user.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9a\x01\n\x04User\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x11\n\x04role\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x15\n\x05\x65mail\x18\x04 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\"`\n\x11\x43reateUserRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12 \n\x04user\x18\x02 \x01(\x0b\x32\r.gateway.UserB\x03\xe0\x41\x02\x12\x14\n\x07user_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"#\n\x0eGetUserRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x84\x01\n\x10ListUsersRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"^\n\x11ListUsersResponse\x12\x1c\n\x05users\x18\x01 \x03(\x0b\x32\r.gateway.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"5\n\x11UpdateUserRequest\x12 \n\x04user\x18\x01 \x01(\x0b\x32\r.gateway.UserB\x03\xe0\x41\x02\"&\n\x11\x44\x65leteUserRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _USER.fields_by_name['name']._options = None
  _USER.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _USER.fields_by_name['display_name']._options = None
  _USER.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _USER.fields_by_name['create_time']._options = None
  _USER.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _USER.fields_by_name['role']._options = None
  _USER.fields_by_name['role']._serialized_options = b'\340A\002'
  _USER.fields_by_name['email']._options = None
  _USER.fields_by_name['email']._serialized_options = b'\340A\002\340A\005'
  _CREATEUSERREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEUSERREQUEST.fields_by_name['user']._options = None
  _CREATEUSERREQUEST.fields_by_name['user']._serialized_options = b'\340A\002'
  _CREATEUSERREQUEST.fields_by_name['user_id']._options = None
  _CREATEUSERREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _GETUSERREQUEST.fields_by_name['name']._options = None
  _GETUSERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTUSERSREQUEST.fields_by_name['parent']._options = None
  _LISTUSERSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTUSERSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTUSERSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTUSERSREQUEST.fields_by_name['filter']._options = None
  _LISTUSERSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTUSERSREQUEST.fields_by_name['order_by']._options = None
  _LISTUSERSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATEUSERREQUEST.fields_by_name['user']._options = None
  _UPDATEUSERREQUEST.fields_by_name['user']._serialized_options = b'\340A\002'
  _DELETEUSERREQUEST.fields_by_name['name']._options = None
  _DELETEUSERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _USER._serialized_start=98
  _USER._serialized_end=252
  _CREATEUSERREQUEST._serialized_start=254
  _CREATEUSERREQUEST._serialized_end=350
  _GETUSERREQUEST._serialized_start=352
  _GETUSERREQUEST._serialized_end=387
  _LISTUSERSREQUEST._serialized_start=390
  _LISTUSERSREQUEST._serialized_end=522
  _LISTUSERSRESPONSE._serialized_start=524
  _LISTUSERSRESPONSE._serialized_end=618
  _UPDATEUSERREQUEST._serialized_start=620
  _UPDATEUSERREQUEST._serialized_end=673
  _DELETEUSERREQUEST._serialized_start=675
  _DELETEUSERREQUEST._serialized_end=713
# @@protoc_insertion_point(module_scope)
