# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/deployment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gateway/deployment.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdb\x05\n\nDeployment\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x08 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x30\n\x05state\x18\x05 \x01(\x0e\x32\x19.gateway.Deployment.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12 \n\x10predict_http_uri\x18\t \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12!\n\x11min_replica_count\x18\r \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11max_replica_count\x18\x0e \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fmax_addon_count\x18\x10 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x05\x12\x1b\n\x0b\x61\x64\x64on_count\x18\x11 \x01(\x05\x42\x06\xe0\x41\x03\xe0\x41\x05\x12\x1a\n\nbase_model\x18\x12 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12+\n\x1b\x64isaggregated_prefill_count\x18\x13 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1e\n\x0emax_batch_size\x18\x14 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x30\n\x0e\x61ws_deployment\x18\x15 \x01(\x0b\x32\x16.gateway.AwsDeploymentH\x00\x12\x30\n\x0egcp_deployment\x18\x16 \x01(\x0b\x32\x16.gateway.GcpDeploymentH\x00\x12\x12\n\nno_knative\x18\x17 \x01(\x08\"_\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x42\x06\n\x04type\"\x0f\n\rAwsDeployment\"\x0f\n\rGcpDeployment\"s\n\x17\x43reateDeploymentRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12,\n\ndeployment\x18\x02 \x01(\x0b\x32\x13.gateway.DeploymentB\x03\xe0\x41\x02\x12\x15\n\x08model_id\x18\x04 \x01(\tB\x03\xe0\x41\x01\")\n\x14GetDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x8a\x01\n\x16ListDeploymentsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"p\n\x17ListDeploymentsResponse\x12(\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32\x13.gateway.Deployment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"G\n\x17UpdateDeploymentRequest\x12,\n\ndeployment\x18\x01 \x01(\x0b\x32\x13.gateway.DeploymentB\x03\xe0\x41\x02\",\n\x17\x44\x65leteDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"+\n\x16StartDeploymentRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.deployment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _DEPLOYMENT.fields_by_name['name']._options = None
  _DEPLOYMENT.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['display_name']._options = None
  _DEPLOYMENT.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _DEPLOYMENT.fields_by_name['description']._options = None
  _DEPLOYMENT.fields_by_name['description']._serialized_options = b'\340A\001'
  _DEPLOYMENT.fields_by_name['create_time']._options = None
  _DEPLOYMENT.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['state']._options = None
  _DEPLOYMENT.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['status']._options = None
  _DEPLOYMENT.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['predict_http_uri']._options = None
  _DEPLOYMENT.fields_by_name['predict_http_uri']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['min_replica_count']._options = None
  _DEPLOYMENT.fields_by_name['min_replica_count']._serialized_options = b'\340A\001\340A\005'
  _DEPLOYMENT.fields_by_name['max_replica_count']._options = None
  _DEPLOYMENT.fields_by_name['max_replica_count']._serialized_options = b'\340A\001\340A\005'
  _DEPLOYMENT.fields_by_name['max_addon_count']._options = None
  _DEPLOYMENT.fields_by_name['max_addon_count']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['addon_count']._options = None
  _DEPLOYMENT.fields_by_name['addon_count']._serialized_options = b'\340A\003\340A\005'
  _DEPLOYMENT.fields_by_name['base_model']._options = None
  _DEPLOYMENT.fields_by_name['base_model']._serialized_options = b'\340A\002\340A\005'
  _DEPLOYMENT.fields_by_name['disaggregated_prefill_count']._options = None
  _DEPLOYMENT.fields_by_name['disaggregated_prefill_count']._serialized_options = b'\340A\001\340A\005'
  _DEPLOYMENT.fields_by_name['max_batch_size']._options = None
  _DEPLOYMENT.fields_by_name['max_batch_size']._serialized_options = b'\340A\001\340A\005'
  _CREATEDEPLOYMENTREQUEST.fields_by_name['parent']._options = None
  _CREATEDEPLOYMENTREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATEDEPLOYMENTREQUEST.fields_by_name['deployment']._options = None
  _CREATEDEPLOYMENTREQUEST.fields_by_name['deployment']._serialized_options = b'\340A\002'
  _CREATEDEPLOYMENTREQUEST.fields_by_name['model_id']._options = None
  _CREATEDEPLOYMENTREQUEST.fields_by_name['model_id']._serialized_options = b'\340A\001'
  _GETDEPLOYMENTREQUEST.fields_by_name['name']._options = None
  _GETDEPLOYMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTDEPLOYMENTSREQUEST.fields_by_name['parent']._options = None
  _LISTDEPLOYMENTSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTDEPLOYMENTSREQUEST.fields_by_name['page_size']._options = None
  _LISTDEPLOYMENTSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTDEPLOYMENTSREQUEST.fields_by_name['page_token']._options = None
  _LISTDEPLOYMENTSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTDEPLOYMENTSREQUEST.fields_by_name['filter']._options = None
  _LISTDEPLOYMENTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTDEPLOYMENTSREQUEST.fields_by_name['order_by']._options = None
  _LISTDEPLOYMENTSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATEDEPLOYMENTREQUEST.fields_by_name['deployment']._options = None
  _UPDATEDEPLOYMENTREQUEST.fields_by_name['deployment']._serialized_options = b'\340A\002'
  _DELETEDEPLOYMENTREQUEST.fields_by_name['name']._options = None
  _DELETEDEPLOYMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _STARTDEPLOYMENTREQUEST.fields_by_name['name']._options = None
  _STARTDEPLOYMENTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _DEPLOYMENT._serialized_start=126
  _DEPLOYMENT._serialized_end=857
  _DEPLOYMENT_STATE._serialized_start=754
  _DEPLOYMENT_STATE._serialized_end=849
  _AWSDEPLOYMENT._serialized_start=859
  _AWSDEPLOYMENT._serialized_end=874
  _GCPDEPLOYMENT._serialized_start=876
  _GCPDEPLOYMENT._serialized_end=891
  _CREATEDEPLOYMENTREQUEST._serialized_start=893
  _CREATEDEPLOYMENTREQUEST._serialized_end=1008
  _GETDEPLOYMENTREQUEST._serialized_start=1010
  _GETDEPLOYMENTREQUEST._serialized_end=1051
  _LISTDEPLOYMENTSREQUEST._serialized_start=1054
  _LISTDEPLOYMENTSREQUEST._serialized_end=1192
  _LISTDEPLOYMENTSRESPONSE._serialized_start=1194
  _LISTDEPLOYMENTSRESPONSE._serialized_end=1306
  _UPDATEDEPLOYMENTREQUEST._serialized_start=1308
  _UPDATEDEPLOYMENTREQUEST._serialized_end=1379
  _DELETEDEPLOYMENTREQUEST._serialized_start=1381
  _DELETEDEPLOYMENTREQUEST._serialized_end=1425
  _STARTDEPLOYMENTREQUEST._serialized_start=1427
  _STARTDEPLOYMENTREQUEST._serialized_end=1470
# @@protoc_insertion_point(module_scope)
