# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/account.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe4\x02\n\x07\x41\x63\x63ount\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x05\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12#\n\x13prometheus_endpoint\x18\x04 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12/\n\x1f\x61thena_cost_usage_report_bucket\x18\x05 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12:\n\x0c\x61\x63\x63ount_type\x18\x06 \x01(\x0e\x32\x1c.gateway.Account.AccountTypeB\x06\xe0\x41\x03\xe0\x41\x05\"]\n\x0b\x41\x63\x63ountType\x12\x1c\n\x18\x41\x43\x43OUNT_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDEVELOPER\x10\x01\x12\x0e\n\nENTERPRISE\x10\x02\x12\x11\n\rDEVELOPER_PRO\x10\x03\"W\n\x14\x43reateAccountRequest\x12&\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x10.gateway.AccountB\x03\xe0\x41\x02\x12\x17\n\naccount_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"&\n\x11GetAccountRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"r\n\x13ListAccountsRequest\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"g\n\x14ListAccountsResponse\x12\"\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x10.gateway.Account\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\">\n\x14UpdateAccountRequest\x12&\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x10.gateway.AccountB\x03\xe0\x41\x02\")\n\x14\x44\x65leteAccountRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.account_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _ACCOUNT.fields_by_name['name']._options = None
  _ACCOUNT.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _ACCOUNT.fields_by_name['display_name']._options = None
  _ACCOUNT.fields_by_name['display_name']._serialized_options = b'\340A\005'
  _ACCOUNT.fields_by_name['create_time']._options = None
  _ACCOUNT.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _ACCOUNT.fields_by_name['prometheus_endpoint']._options = None
  _ACCOUNT.fields_by_name['prometheus_endpoint']._serialized_options = b'\340A\001\340A\005'
  _ACCOUNT.fields_by_name['athena_cost_usage_report_bucket']._options = None
  _ACCOUNT.fields_by_name['athena_cost_usage_report_bucket']._serialized_options = b'\340A\001\340A\005'
  _ACCOUNT.fields_by_name['account_type']._options = None
  _ACCOUNT.fields_by_name['account_type']._serialized_options = b'\340A\003\340A\005'
  _CREATEACCOUNTREQUEST.fields_by_name['account']._options = None
  _CREATEACCOUNTREQUEST.fields_by_name['account']._serialized_options = b'\340A\002'
  _CREATEACCOUNTREQUEST.fields_by_name['account_id']._options = None
  _CREATEACCOUNTREQUEST.fields_by_name['account_id']._serialized_options = b'\340A\002'
  _GETACCOUNTREQUEST.fields_by_name['name']._options = None
  _GETACCOUNTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTACCOUNTSREQUEST.fields_by_name['page_size']._options = None
  _LISTACCOUNTSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTACCOUNTSREQUEST.fields_by_name['page_token']._options = None
  _LISTACCOUNTSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTACCOUNTSREQUEST.fields_by_name['filter']._options = None
  _LISTACCOUNTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTACCOUNTSREQUEST.fields_by_name['order_by']._options = None
  _LISTACCOUNTSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATEACCOUNTREQUEST.fields_by_name['account']._options = None
  _UPDATEACCOUNTREQUEST.fields_by_name['account']._serialized_options = b'\340A\002'
  _DELETEACCOUNTREQUEST.fields_by_name['name']._options = None
  _DELETEACCOUNTREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _ACCOUNT._serialized_start=101
  _ACCOUNT._serialized_end=457
  _ACCOUNT_ACCOUNTTYPE._serialized_start=364
  _ACCOUNT_ACCOUNTTYPE._serialized_end=457
  _CREATEACCOUNTREQUEST._serialized_start=459
  _CREATEACCOUNTREQUEST._serialized_end=546
  _GETACCOUNTREQUEST._serialized_start=548
  _GETACCOUNTREQUEST._serialized_end=586
  _LISTACCOUNTSREQUEST._serialized_start=588
  _LISTACCOUNTSREQUEST._serialized_end=702
  _LISTACCOUNTSRESPONSE._serialized_start=704
  _LISTACCOUNTSRESPONSE._serialized_end=807
  _UPDATEACCOUNTREQUEST._serialized_start=809
  _UPDATEACCOUNTREQUEST._serialized_end=871
  _DELETEACCOUNTREQUEST._serialized_start=873
  _DELETEACCOUNTREQUEST._serialized_end=914
# @@protoc_insertion_point(module_scope)
