# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/cluster.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdb\x04\n\x07\x43luster\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x06 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12*\n\x0bgke_cluster\x18\x02 \x01(\x0b\x32\x13.gateway.GkeClusterH\x00\x12*\n\x0b\x65ks_cluster\x18\x07 \x01(\x0b\x32\x13.gateway.EksClusterH\x00\x12,\n\x0c\x66\x61ke_cluster\x18\x03 \x01(\x0b\x32\x14.gateway.FakeClusterH\x00\x12\x34\n\x10minikube_cluster\x18\x04 \x01(\x0b\x32\x18.gateway.MinikubeClusterH\x00\x12;\n\x0b\x61nnotations\x18\n \x03(\x0b\x32!.gateway.Cluster.AnnotationsEntryB\x03\xe0\x41\x01\x12-\n\x05state\x18\x05 \x01(\x0e\x32\x16.gateway.Cluster.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x0e\n\x0c\x63luster_type\"\xa4\x01\n\nGkeCluster\x12\x1a\n\nproject_id\x18\x01 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x18\n\x08location\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x1c\n\x0c\x63luster_name\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1d\n\rrepository_id\x18\x05 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12#\n\x13storage_bucket_name\x18\x06 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"\xfa\x02\n\nEksCluster\x12\x1e\n\x0e\x61ws_account_id\x18\t \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12&\n\x16\x66ireworks_manager_role\x18\x01 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x16\n\x06region\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x1c\n\x0c\x63luster_role\x18\x04 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\'\n\x17\x63luster_autoscaler_role\x18\n \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12 \n\x10system_node_role\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1a\n\nsubnet_ids\x18\x05 \x03(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1c\n\x0c\x63luster_name\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0frepository_name\x18\x06 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12#\n\x13storage_bucket_name\x18\x08 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12#\n\x13node_security_group\x18\x0b \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"!\n\x0fMinikubeCluster\x12\x0e\n\x06server\x18\x01 \x01(\t\"I\n\x0b\x46\x61keCluster\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x14\n\x0c\x63luster_name\x18\x03 \x01(\t\"l\n\x14\x43reateClusterRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12&\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x10.gateway.ClusterB\x03\xe0\x41\x02\x12\x17\n\ncluster_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"&\n\x11GetClusterRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\",\n\x17ReconcileClusterRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x87\x01\n\x13ListClustersRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"g\n\x14ListClustersResponse\x12\"\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x10.gateway.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\">\n\x14UpdateClusterRequest\x12&\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.gateway.ClusterB\x03\xe0\x41\x02\")\n\x14\x44\x65leteClusterRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"4\n\x1fGetClusterConnectionInfoRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\":\n\x15\x43lusterConnectionInfo\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61_data\x18\x02 \x01(\tB\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.cluster_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _CLUSTER_ANNOTATIONSENTRY._options = None
  _CLUSTER_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CLUSTER.fields_by_name['name']._options = None
  _CLUSTER.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _CLUSTER.fields_by_name['display_name']._options = None
  _CLUSTER.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _CLUSTER.fields_by_name['create_time']._options = None
  _CLUSTER.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _CLUSTER.fields_by_name['annotations']._options = None
  _CLUSTER.fields_by_name['annotations']._serialized_options = b'\340A\001'
  _CLUSTER.fields_by_name['state']._options = None
  _CLUSTER.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _CLUSTER.fields_by_name['status']._options = None
  _CLUSTER.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _GKECLUSTER.fields_by_name['project_id']._options = None
  _GKECLUSTER.fields_by_name['project_id']._serialized_options = b'\340A\002\340A\005'
  _GKECLUSTER.fields_by_name['location']._options = None
  _GKECLUSTER.fields_by_name['location']._serialized_options = b'\340A\002\340A\005'
  _GKECLUSTER.fields_by_name['cluster_name']._options = None
  _GKECLUSTER.fields_by_name['cluster_name']._serialized_options = b'\340A\001\340A\005'
  _GKECLUSTER.fields_by_name['repository_id']._options = None
  _GKECLUSTER.fields_by_name['repository_id']._serialized_options = b'\340A\001\340A\005'
  _GKECLUSTER.fields_by_name['storage_bucket_name']._options = None
  _GKECLUSTER.fields_by_name['storage_bucket_name']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['aws_account_id']._options = None
  _EKSCLUSTER.fields_by_name['aws_account_id']._serialized_options = b'\340A\002\340A\005'
  _EKSCLUSTER.fields_by_name['fireworks_manager_role']._options = None
  _EKSCLUSTER.fields_by_name['fireworks_manager_role']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['region']._options = None
  _EKSCLUSTER.fields_by_name['region']._serialized_options = b'\340A\002\340A\005'
  _EKSCLUSTER.fields_by_name['cluster_role']._options = None
  _EKSCLUSTER.fields_by_name['cluster_role']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['cluster_autoscaler_role']._options = None
  _EKSCLUSTER.fields_by_name['cluster_autoscaler_role']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['system_node_role']._options = None
  _EKSCLUSTER.fields_by_name['system_node_role']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['subnet_ids']._options = None
  _EKSCLUSTER.fields_by_name['subnet_ids']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['cluster_name']._options = None
  _EKSCLUSTER.fields_by_name['cluster_name']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['repository_name']._options = None
  _EKSCLUSTER.fields_by_name['repository_name']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['storage_bucket_name']._options = None
  _EKSCLUSTER.fields_by_name['storage_bucket_name']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['node_security_group']._options = None
  _EKSCLUSTER.fields_by_name['node_security_group']._serialized_options = b'\340A\001\340A\005'
  _CREATECLUSTERREQUEST.fields_by_name['parent']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATECLUSTERREQUEST.fields_by_name['cluster']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['cluster']._serialized_options = b'\340A\002'
  _CREATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\340A\002'
  _GETCLUSTERREQUEST.fields_by_name['name']._options = None
  _GETCLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _RECONCILECLUSTERREQUEST.fields_by_name['name']._options = None
  _RECONCILECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTCLUSTERSREQUEST.fields_by_name['parent']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTCLUSTERSREQUEST.fields_by_name['order_by']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster']._serialized_options = b'\340A\002'
  _DELETECLUSTERREQUEST.fields_by_name['name']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _GETCLUSTERCONNECTIONINFOREQUEST.fields_by_name['name']._options = None
  _GETCLUSTERCONNECTIONINFOREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _CLUSTER._serialized_start=123
  _CLUSTER._serialized_end=726
  _CLUSTER_ANNOTATIONSENTRY._serialized_start=577
  _CLUSTER_ANNOTATIONSENTRY._serialized_end=627
  _CLUSTER_STATE._serialized_start=629
  _CLUSTER_STATE._serialized_end=710
  _GKECLUSTER._serialized_start=729
  _GKECLUSTER._serialized_end=893
  _EKSCLUSTER._serialized_start=896
  _EKSCLUSTER._serialized_end=1274
  _MINIKUBECLUSTER._serialized_start=1276
  _MINIKUBECLUSTER._serialized_end=1309
  _FAKECLUSTER._serialized_start=1311
  _FAKECLUSTER._serialized_end=1384
  _CREATECLUSTERREQUEST._serialized_start=1386
  _CREATECLUSTERREQUEST._serialized_end=1494
  _GETCLUSTERREQUEST._serialized_start=1496
  _GETCLUSTERREQUEST._serialized_end=1534
  _RECONCILECLUSTERREQUEST._serialized_start=1536
  _RECONCILECLUSTERREQUEST._serialized_end=1580
  _LISTCLUSTERSREQUEST._serialized_start=1583
  _LISTCLUSTERSREQUEST._serialized_end=1718
  _LISTCLUSTERSRESPONSE._serialized_start=1720
  _LISTCLUSTERSRESPONSE._serialized_end=1823
  _UPDATECLUSTERREQUEST._serialized_start=1825
  _UPDATECLUSTERREQUEST._serialized_end=1887
  _DELETECLUSTERREQUEST._serialized_start=1889
  _DELETECLUSTERREQUEST._serialized_end=1930
  _GETCLUSTERCONNECTIONINFOREQUEST._serialized_start=1932
  _GETCLUSTERCONNECTIONINFOREQUEST._serialized_end=1984
  _CLUSTERCONNECTIONINFO._serialized_start=1986
  _CLUSTERCONNECTIONINFO._serialized_end=2044
# @@protoc_insertion_point(module_scope)
