# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/sign_in.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/sign_in.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\"\x8f\x01\n\rSignInRequest\x12\x41\n\x0eoauth_provider\x18\x01 \x01(\x0e\x32$.gateway.SignInRequest.OAuthProviderB\x03\xe0\x41\x02\";\n\rOAuthProvider\x12\x1e\n\x1aOAUTH_PROVIDER_UNSPECIFIED\x10\x00\x12\n\n\x06GOOGLE\x10\x01\"3\n\x18GetOAuthArgumentsRequest\x12\x17\n\naccount_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"B\n\x19GetOAuthArgumentsResponse\x12\x12\n\nissuer_url\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\tB\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.sign_in_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _SIGNINREQUEST.fields_by_name['oauth_provider']._options = None
  _SIGNINREQUEST.fields_by_name['oauth_provider']._serialized_options = b'\340A\002'
  _GETOAUTHARGUMENTSREQUEST.fields_by_name['account_id']._options = None
  _GETOAUTHARGUMENTSREQUEST.fields_by_name['account_id']._serialized_options = b'\340A\002'
  _SIGNINREQUEST._serialized_start=68
  _SIGNINREQUEST._serialized_end=211
  _SIGNINREQUEST_OAUTHPROVIDER._serialized_start=152
  _SIGNINREQUEST_OAUTHPROVIDER._serialized_end=211
  _GETOAUTHARGUMENTSREQUEST._serialized_start=213
  _GETOAUTHARGUMENTSREQUEST._serialized_end=264
  _GETOAUTHARGUMENTSRESPONSE._serialized_start=266
  _GETOAUTHARGUMENTSRESPONSE._serialized_end=332
# @@protoc_insertion_point(module_scope)
